Except for coef.mvr, these functions are mostly used inside
other functions.
coef.mvr is used to extract the regression coefficients of a
model, i.e. the $B$ in $y = XB$. An array of dimension
c(nxvar, nyvar, length(comps)) is returned. If cumulative = TRUE, coef()[,,comps[i]] are
the coefficients for models with comps[i] components, for
$i = 1, \ldots, length(comps)$. Also, if intercept = TRUE,
the first dimension is $nxvar + 1$, with the intercept
coefficients as the first row.
If cumulative = FALSE, however, coef()[,,comps[i]] are
the coefficients for a model with only the component comps[i],
i.e. the contribution of the component comps[i] on the
regression coefficients.
model.frame.mvr returns the model frame; i.e. a data frame with
all variables neccessary to generate the model matrix. See
model.frame for details.
model.matrix.mvr returns the (possibly coded) matrix used as
$X$ in the fitting. See model.matrix for
details.
prednames, respnames and compnames extract the
names of the $X$ variables, responses and components,
respectively. With intercept = TRUE in prednames,
the name of the intercept variable (i.e. "(Intercept)") is
returned as well. If explvar = TRUE in compnames, the
explained variance for each component is appended to the component
names. For optimal formatting of the explained variances when not all
components are to be used, one should specify the desired components
with the argument comps.
explvar extracts the amount of $X$ variance (in per cent)
explained by for each component in the model.