Fits a PLSR model with the orthogonal scores algorithm (aka the NIPALS algorithm).
oscorespls.fit(
X,
Y,
ncomp,
center = TRUE,
stripped = FALSE,
tol = .Machine$double.eps^0.5,
maxit = 100,
...
)A list containing the following components is returned:
an array of regression coefficients for 1, ...,
ncomp components. The dimensions of coefficients are
c(nvar, npred, ncomp) with nvar the number of X
variables and npred the number of variables to be predicted in
Y.
a matrix of scores.
a matrix of loadings.
a matrix of loading weights.
a matrix of Y-scores.
a matrix of Y-loadings.
the projection matrix used to convert X to scores.
a vector of means of the X variables.
a vector of means of the Y variables.
an
array of fitted values. The dimensions of fitted.values are
c(nobj, npred, ncomp) with nobj the number samples and
npred the number of Y variables.
an array of
regression residuals. It has the same dimensions as fitted.values.
a vector with the amount of X-variance explained by each component.
Total variance in X.
If stripped is TRUE, only the components coefficients,
Xmeans and Ymeans are returned.
a matrix of observations. NAs and Infs are not
allowed.
a vector or matrix of responses. NAs and Infs are
not allowed.
the number of components to be used in the modelling.
logical, determines if the \(X\) and \(Y\) matrices are mean centered or not. Default is to perform mean centering.
logical. If TRUE the calculations are stripped as
much as possible for speed; this is meant for use with cross-validation or
simulations when only the coefficients are needed. Defaults to
FALSE.
numeric. The tolerance used for determining convergence in multi-response models.
positive integer. The maximal number of iterations used in the internal Eigenvector calculation.
other arguments. Currently ignored.
Ron Wehrens and Bjørn-Helge Mevik
This function should not be called directly, but through the generic
functions plsr or mvr with the argument
method="oscorespls". It implements the orthogonal scores algorithm,
as described in Martens and Næs (1989). This is one of the two
“classical” PLSR algorithms, the other being the orthogonal loadings
algorithm.
Martens, H., Næs, T. (1989) Multivariate calibration. Chichester: Wiley.
mvr plsr pcr
kernelpls.fit widekernelpls.fit
simpls.fit