simpls.fit: Sijmen de Jong's SIMPLS
Description
Fits a PLSR model with the SIMPLS algorithm.Usage
simpls.fit(X, Y, ncomp, stripped = FALSE, ...)
Value
- A list containing the following components is returned:
- coefficientsan array of regression coefficients for 1, ...,
ncomp components. The dimensions of coefficients are
c(nvar, npred, ncomp) with nvar the number
of X variables and npred the number of variables to be
predicted in Y. - scoresa matrix of scores.
- loadingsa matrix of loadings.
- Yscoresa matrix of Y-scores.
- Yloadingsa matrix of Y-loadings.
- projectionthe projection matrix used to convert X to scores.
- Xmeansa vector of means of the X variables.
- Ymeansa vector of means of the Y variables.
- fitted.valuesan array of fitted values. The dimensions of
fitted.values are c(nobj, npred, ncomp) with
nobj the number samples and npred the number of
Y variables. - residualsan array of regression residuals. It has the same
dimensions as
fitted.values. - Xvara vector with the amount of X-variance explained by each
number of components.
- XtotvarTotal variance in
X. - If
stripped is TRUE, only the components
coefficients, Xmeans and Ymeans are returned.
Details
This function should not be called directly, but through
the generic functions plsr or mvr with the argument
method="simpls". SIMPLS is much faster than the NIPALS algorithm,
especially when the number of X variables increases, but gives
slightly different results in the case of multivariate Y. SIMPLS truly
maximises the covariance criterion. According to de Jong, the standard
PLS2 algorithms lie closer to ordinary least-squares regression where
a precise fit is sought; SIMPLS lies closer to PCR with stable
predictions.References
de Jong, S. (1993) SIMPLS: an alternative approach to partial least
squares regression. Chemometrics and Intelligent Laboratory Systems,
18, 251--263.